@@ -222,39 +222,13 @@ media_key_free (MediaKey *key)
         g_free (key);
 }
 
-static char *
-get_term_command (GsdMediaKeysManager *manager)
-{
-        char *cmd_term, *cmd_args;;
-        char *cmd = NULL;
-        GSettings *settings;
-
-        settings = g_settings_new ("org.gnome.desktop.default-applications.terminal");
-        cmd_term = g_settings_get_string (settings, "exec");
-        if (cmd_term[0] == '\0')
-                cmd_term = g_strdup ("gnome-terminal");
-
-        cmd_args = g_settings_get_string (settings, "exec-arg");
-        if (strcmp (cmd_term, "") != 0) {
-                cmd = g_strdup_printf ("%s %s -e", cmd_term, cmd_args);
-        } else {
-                cmd = g_strdup_printf ("%s -e", cmd_term);
-        }
-
-        g_free (cmd_args);
-        g_free (cmd_term);
-        g_object_unref (settings);
-
-        return cmd;
-}
-
-static char **
-get_keyring_env (GsdMediaKeysManager *manager)
+static void
+set_launch_context_env (GsdMediaKeysManager *manager,
+			GAppLaunchContext   *launch_context)
 {
 	GError *error = NULL;
 	GVariant *variant, *item;
 	GVariantIter *iter;
-	char **envp;
 
 	variant = g_dbus_connection_call_sync (manager->priv->connection,
 					       GNOME_KEYRING_DBUS_NAME,
@@ -270,12 +244,9 @@ get_keyring_env (GsdMediaKeysManager *manager)
 	if (variant == NULL) {
 		g_warning ("Failed to call GetEnvironment on keyring daemon: %s", error->message);
 		g_error_free (error);
-		return NULL;
+		return;
 	}
 
-	envp = g_get_environ ();
-	envp = g_environ_unsetenv (envp, "DESKTOP_AUTOSTART_ID");
-
 	g_variant_get (variant, "(a{ss})", &iter);
 
 	while ((item = g_variant_iter_next_value (iter))) {
@@ -287,7 +258,7 @@ get_keyring_env (GsdMediaKeysManager *manager)
 			       &key,
 			       &value);
 
-		envp = g_environ_setenv (envp, key, value, TRUE);
+		g_app_launch_context_setenv (launch_context, key, value);
 
 		g_variant_unref (item);
 		g_free (key);
@@ -296,57 +267,6 @@ get_keyring_env (GsdMediaKeysManager *manager)
 
 	g_variant_iter_free (iter);
 	g_variant_unref (variant);
-
-	return envp;
-}
-
-static void
-execute (GsdMediaKeysManager *manager,
-         char                *cmd,
-         gboolean             need_term)
-{
-        gboolean retval;
-        char   **argv;
-        int      argc;
-        char    *exec;
-        char    *term = NULL;
-        GError  *error = NULL;
-
-        retval = FALSE;
-
-        if (need_term)
-                term = get_term_command (manager);
-
-        if (term) {
-                exec = g_strdup_printf ("%s %s", term, cmd);
-                g_free (term);
-        } else {
-                exec = g_strdup (cmd);
-        }
-
-        if (g_shell_parse_argv (exec, &argc, &argv, NULL)) {
-		char   **envp;
-
-		envp = get_keyring_env (manager);
-
-                retval = g_spawn_async (g_get_home_dir (),
-                                        argv,
-                                        envp,
-                                        G_SPAWN_SEARCH_PATH,
-                                        NULL,
-                                        NULL,
-                                        NULL,
-                                        &error);
-
-                g_strfreev (argv);
-                g_strfreev (envp);
-        }
-
-        if (retval == FALSE) {
-                g_warning ("Couldn't execute command: %s: %s", exec, error->message);
-                g_error_free (error);
-        }
-        g_free (exec);
 }
 
 static char *
@@ -788,8 +708,9 @@ init_kbd (GsdMediaKeysManager *manager)
 }
 
 static void
-launch_app (GAppInfo *app_info,
-	    gint64    timestamp)
+launch_app (GsdMediaKeysManager *manager,
+	    GAppInfo            *app_info,
+	    gint64               timestamp)
 {
 	GError *error = NULL;
         GdkAppLaunchContext *launch_context;
@@ -797,6 +718,7 @@ launch_app (GAppInfo *app_info,
         /* setup the launch context so the startup notification is correct */
         launch_context = gdk_display_get_app_launch_context (gdk_display_get_default ());
         gdk_app_launch_context_set_timestamp (launch_context, timestamp);
+        set_launch_context_env (manager, G_APP_LAUNCH_CONTEXT (launch_context));
 
 	if (!g_app_info_launch (app_info, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error)) {
 		g_warning ("Could not launch '%s': %s",
@@ -807,6 +729,18 @@ launch_app (GAppInfo *app_info,
         g_object_unref (launch_context);
 }
 
+static void
+execute (GsdMediaKeysManager *manager,
+         char                *cmd,
+         gint64               timestamp)
+{
+	GAppInfo *app_info;
+
+	app_info = g_app_info_create_from_commandline (cmd, NULL, G_APP_INFO_CREATE_NONE, NULL);
+	launch_app (manager, app_info, timestamp);
+	g_object_unref (app_info);
+}
+
 static void
 do_url_action (GsdMediaKeysManager *manager,
                const char          *scheme,
@@ -816,7 +750,7 @@ do_url_action (GsdMediaKeysManager *manager,
 
         app_info = g_app_info_get_default_for_uri_scheme (scheme);
         if (app_info != NULL) {
-                launch_app (app_info, timestamp);
+                launch_app (manager, app_info, timestamp);
                 g_object_unref (app_info);
         } else {
                 g_warning ("Could not find default application for '%s' scheme", scheme);
@@ -831,7 +765,7 @@ do_media_action (GsdMediaKeysManager *manager,
 
         app_info = g_app_info_get_default_for_type ("audio/x-vorbis+ogg", FALSE);
         if (app_info != NULL) {
-                launch_app (app_info, timestamp);
+                launch_app (manager, app_info, timestamp);
                 g_object_unref (app_info);
         } else {
                 g_warning ("Could not find default application for '%s' mime-type", "audio/x-vorbis+ogg");
@@ -972,7 +906,7 @@ do_execute_desktop_or_desktop (GsdMediaKeysManager *manager,
                 app_info = g_desktop_app_info_new (alt_desktop);
 
         if (app_info != NULL) {
-                launch_app (G_APP_INFO (app_info), timestamp);
+                launch_app (manager, G_APP_INFO (app_info), timestamp);
                 g_object_unref (app_info);
                 return;
         }
@@ -2023,7 +1957,7 @@ do_custom_action (GsdMediaKeysManager *manager,
 {
         g_debug ("Launching custom action for key (on device id %d)", deviceid);
 
-	execute (manager, key->custom_command, FALSE);
+	execute (manager, key->custom_command, timestamp);
 }
 
 static gboolean
